@@ -76,9 +76,9 @@
 #' @examples 
 #' # Replication of results in Tone(2002, p.39)
 #' data("Power_plants")
-#' data_example <- read_data(Power_plants,
-#'                           ni = 4,
-#'                           no = 2)
+#' data_example <- make_deadata(Power_plants,
+#'                              ni = 4,
+#'                              no = 2)
 #' result <- model_sbmsupereff(data_example,
 #'                             orientation = "io",
 #'                             rts = "crs") 
@@ -111,7 +111,7 @@ model_sbmsupereff <-
     
   # Cheking whether datadea is of class "deadata" or not...  
   if (!is.deadata(datadea)) {
-    stop("Data should be of class deadata. Run read_data function first!")
+    stop("Data should be of class deadata. Run make_deadata function first!")
   }
     
   # Checking undesirable io and rts
